@@ -83,14 +83,23 @@ listing.append('geometry')
 from kineticstoolkit import dev  # noqa
 unstable_listing.append('dev')
 
-from kineticstoolkit import inversedynamics  # noqa
-unstable_listing.append('inversedynamics')
+try:
+    from kineticstoolkit import inversedynamics  # noqa
+    unstable_listing.append('inversedynamics')
+except:
+    pass
 
-from kineticstoolkit import emg  # noqa
-unstable_listing.append('emg')
+try:
+    from kineticstoolkit import emg  # noqa
+    unstable_listing.append('emg')
+except:
+    pass
 
-from kineticstoolkit import anthropometrics  # noqa
-unstable_listing.append('anthropometrics')
+try:
+    from kineticstoolkit import anthropometrics  # noqa
+    unstable_listing.append('anthropometrics')
+except:
+    pass
 
 from kineticstoolkit import config  # noqa
 
