@@ -116,13 +116,10 @@ def read_c3d_file(filename: str) -> TimeSeries:
     return output
 
 
-@unstable
 def write_c3d_file(filename: str, markers: TimeSeries) -> None:
     """
     Write a markers TimeSeries to a C3D file.
 
-    This is the mirror operation to read_c3d_file.
-
     Parameters
     ----------
     filename
@@ -134,11 +131,8 @@ def write_c3d_file(filename: str, markers: TimeSeries) -> None:
 
     Notes
     -----
-    - This function relies on `ezc3d`, which is available on
-      conda-forge and on git-hub. Please install ezc3d before using
-      read_c3d_file. https://github.com/pyomeca/ezc3d
-
-    - The point unit in the output c3d is m.
+    This function relies on `ezc3d`. Please install ezc3d before using
+    write_c3d_file. https://github.com/pyomeca/ezc3d
 
     """
     sample_rate = (markers.time.shape[0] - 1) / (
@@ -361,7 +355,6 @@ def read_n3d_file(filename: str, labels: Sequence[str] = []) -> TimeSeries:
 #            return(the_timeseries)
 
 
-@unstable
 def create_cluster(
         markers: TimeSeries,
         /,
@@ -369,6 +362,11 @@ def create_cluster(
     """
     Create a cluster definition based on a static acquisition.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.7, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -414,7 +412,6 @@ def create_cluster(
     return output
 
 
-@unstable
 def extend_cluster(
         markers: TimeSeries,
         /,
@@ -423,6 +420,11 @@ def extend_cluster(
     """
     Add a point to an existing cluster.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.7, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -447,7 +449,6 @@ def extend_cluster(
     return cluster
 
 
-@unstable
 def track_cluster(
         markers: TimeSeries,
         /,
@@ -461,6 +462,11 @@ def track_cluster(
     Fits a cluster to a TimeSeries and reconstructs a solidified version of
     all the points defined in this cluster.
 
+    Warning
+    -------
+    This function, which has been introduced in 0.7, is still experimental and
+    may change signature or behaviour in the future.
+
     Parameters
     ----------
     markers
@@ -585,7 +591,7 @@ def write_trc_file(markers: TimeSeries, filename: str) -> None:
 
 # %% Deprecated
 @unstable
-@deprecated(since='master', until='master', details="Use create_cluster().")
+@deprecated(since='master', until='January 2023', details="Use create_cluster().")
 def define_rigid_body(
         kinematics: TimeSeries,
         marker_names: Sequence[str]) -> Dict[str, np.ndarray]:
@@ -612,7 +618,7 @@ def define_rigid_body(
 
 
 @unstable
-@deprecated(since='master', until='master', details="Use track_clusters().")
+@deprecated(since='master', until='January 2023', details="Use track_clusters().")
 def track_rigid_body(
         kinematics: TimeSeries,
         /,
@@ -662,7 +668,7 @@ def track_rigid_body(
 
 
 @unstable
-@deprecated(since='master', until='master', details="No replacement yet.")
+@deprecated(since='master', until='January 2023', details="No replacement yet.")
 def track_rigid_bodies(
         markers: TimeSeries,
         /,
@@ -704,7 +710,7 @@ def track_rigid_bodies(
 
 
 @unstable
-@deprecated(since='master', until='master', details="Use extend_cluster().")
+@deprecated(since='master', until='January 2023', details="Use extend_cluster().")
 def define_local_position(
         kinematics: TimeSeries,
         source_name: str,
